%global luajit_version 2.1

Summary:        Vim-fork focused on extensibility and agility
Name:           neovim
Version:        0.8.2
Release:        4%{?dist}
License:        ASL 2.0
Url:            https://neovim.io
Source0:        https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        sysinit.vim
Source2:        spec-template

Patch3000:      neovim-fix-fortify-source.patch

BuildRequires:  gcc-c++ cmake desktop-file-utils fdupes gettext gperf gcc
BuildRequires:  luajit-devel luajit2.1-luv-devel lua5.1-lpeg lua5.1-mpack
BuildRequires:  jemalloc-devel msgpack-devel libtermkey-devel libuv-devel
BuildRequires:  libvterm-devel unibilium-devel libtree-sitter-devel

Requires:       libvterm luajit2.1-luv libtree-sitter
Recommends:     tree-sitter-cli
Suggests:       (python3-neovim if python3)
Recommends:     xsel

%description
Neovim is a refactor - and sometimes redactor - in the tradition of Vim, which itself derives from Stevie.
It is not a rewrite, but a continuation and extension of Vim. Many rewrites, clones, emulators and imitators
exist; some are very clever, but none are Vim. Neovim strives to be a superset of Vim, notwithstanding some
intentionally removed misfeatures; excepting those few and carefully-considered excisions, Neovim is Vim.
It is built for users who want the good parts of Vim, without compromise, and more.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DPREFER_LUA=OFF \
       -DLUA_PRG=%{_bindir}/luajit \
       -DENABLE_JEMALLOC=ON \
       -DLIBLUV_INCLUDE_DIR=%{_includedir}/luajit-%{luajit_version} \
       -DLIBLUV_LIBRARY=%{_libdir}/luajit/%{luajit_version}/luv.so \
       %{nil}

%cmake_build

%install
%cmake_install

install -p -m 644 %SOURCE1 %{buildroot}%{_datadir}/nvim/sysinit.vim
install -p -m 644 %SOURCE2 %{buildroot}%{_datadir}/nvim/template.spec

desktop-file-install --dir=%{buildroot}%{_datadir}/applications \
    runtime/nvim.desktop
install -Dm0644 runtime/nvim.png %{buildroot}%{_datadir}/pixmaps/nvim.png

%fdupes %{buildroot}%{_datadir}/

find %{buildroot}%{_datadir} \( -name "*.bat" -o -name "*.awk" \) \
    -print -exec chmod -x '{}' \;
%find_lang nvim

%files -f nvim.lang
%license LICENSE.txt
%doc BACKERS.md CONTRIBUTING.md README.md
%{_bindir}/nvim

%{_mandir}/man1/nvim.1*
%{_datadir}/applications/nvim.desktop
%{_datadir}/pixmaps/nvim.png
%{_datadir}/icons/hicolor/128x128/apps/nvim.png

%dir %{_datadir}/nvim
%{_datadir}/nvim/sysinit.vim
%{_datadir}/nvim/template.spec

%dir %{_datadir}/nvim/runtime
%{_datadir}/nvim/runtime/*.vim
%{_datadir}/nvim/runtime/filetype.lua

%dir %{_datadir}/nvim/runtime/autoload
%{_datadir}/nvim/runtime/autoload/*.vim

%dir %{_datadir}/nvim/runtime/autoload/dist
%{_datadir}/nvim/runtime/autoload/dist/ft.vim

%dir %{_datadir}/nvim/runtime/autoload/provider
%{_datadir}/nvim/runtime/autoload/provider/*.vim
%{_datadir}/nvim/runtime/autoload/provider/script_host.rb

%dir %{_datadir}/nvim/runtime/autoload/remote
%{_datadir}/nvim/runtime/autoload/remote/*.vim

%dir %{_datadir}/nvim/runtime/autoload/xml
%{_datadir}/nvim/runtime/autoload/xml/*.vim

%dir %{_datadir}/nvim/runtime/colors
%{_datadir}/nvim/runtime/colors/*.vim

%dir %{_datadir}/nvim/runtime/compiler
%{_datadir}/nvim/runtime/compiler/*.vim

%dir %{_datadir}/nvim/runtime/doc
%{_datadir}/nvim/runtime/doc/tags
%{_datadir}/nvim/runtime/doc/*.txt

%dir %{_datadir}/nvim/runtime/ftplugin
%{_datadir}/nvim/runtime/ftplugin/*.vim
%{_datadir}/nvim/runtime/ftplugin/*.lua
%{_datadir}/nvim/runtime/ftplugin/logtalk.dict

%dir %{_datadir}/nvim/runtime/indent
%{_datadir}/nvim/runtime/indent/*.vim
%{_datadir}/nvim/runtime/indent/query.lua

%dir %{_datadir}/nvim/runtime/indent/testdir/
%{_datadir}/nvim/runtime/indent/testdir/runtest.vim

%dir %{_datadir}/nvim/runtime/keymap
%{_datadir}/nvim/runtime/keymap/*.vim

%dir %{_datadir}/nvim/runtime/lua
%{_datadir}/nvim/runtime/lua/health.lua
%{_datadir}/nvim/runtime/lua/man.lua

%dir %{_datadir}/nvim/runtime/lua/man
%{_datadir}/nvim/runtime/lua/man/health.lua

%dir %{_datadir}/nvim/runtime/lua/vim
%{_datadir}/nvim/runtime/lua/vim/*.lua

%dir %{_datadir}/nvim/runtime/lua/vim/filetype/
%{_datadir}/nvim/runtime/lua/vim/filetype/detect.lua

%dir %{_datadir}/nvim/runtime/lua/vim/lsp/
%{_datadir}/nvim/runtime/lua/vim/lsp/*.lua

%dir %{_datadir}/nvim/runtime/lua/vim/treesitter/
%{_datadir}/nvim/runtime/lua/vim/treesitter/*.lua

%dir %{_datadir}/nvim/runtime/macros
%{_datadir}/nvim/runtime/macros/*.vim
%{_datadir}/nvim/runtime/macros/less.bat
%{_datadir}/nvim/runtime/macros/less.sh

%dir %{_datadir}/nvim/runtime/pack
%dir %{_datadir}/nvim/runtime/pack/dist
%dir %{_datadir}/nvim/runtime/pack/dist/opt

%dir %{_datadir}/nvim/runtime/pack/dist/opt/cfilter
%dir %{_datadir}/nvim/runtime/pack/dist/opt/cfilter/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/cfilter/plugin/cfilter.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/justify
%dir %{_datadir}/nvim/runtime/pack/dist/opt/justify/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/justify/plugin/justify.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/shellmenu
%dir %{_datadir}/nvim/runtime/pack/dist/opt/shellmenu/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/shellmenu/plugin/shellmenu.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/matchit
%dir %{_datadir}/nvim/runtime/pack/dist/opt/matchit/autoload
%{_datadir}/nvim/runtime/pack/dist/opt/matchit/autoload/matchit.vim
%dir %{_datadir}/nvim/runtime/pack/dist/opt/matchit/doc
%{_datadir}/nvim/runtime/pack/dist/opt/matchit/doc/matchit.txt
%{_datadir}/nvim/runtime/pack/dist/opt/matchit/doc/tags
%dir %{_datadir}/nvim/runtime/pack/dist/opt/matchit/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/matchit/plugin/matchit.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/swapmouse
%dir %{_datadir}/nvim/runtime/pack/dist/opt/swapmouse/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/swapmouse/plugin/swapmouse.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/termdebug
%dir %{_datadir}/nvim/runtime/pack/dist/opt/termdebug/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/termdebug/plugin/termdebug.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/vimball
%dir %{_datadir}/nvim/runtime/pack/dist/opt/vimball/plugin
%{_datadir}/nvim/runtime/pack/dist/opt/vimball/plugin/vimballPlugin.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/vimball/autoload
%{_datadir}/nvim/runtime/pack/dist/opt/vimball/autoload/vimball.vim
%{_datadir}/nvim/runtime/autoload/health/*.vim

%dir %{_datadir}/nvim/runtime/pack/dist/opt/vimball/doc
%{_datadir}/nvim/runtime/pack/dist/opt/vimball/doc/tags
%{_datadir}/nvim/runtime/pack/dist/opt/vimball/doc/vimball.txt

%dir %{_datadir}/nvim/runtime/plugin
%{_datadir}/nvim/runtime/plugin/*.vim
%{_datadir}/nvim/runtime/plugin/man.lua

%dir %{_datadir}/nvim/runtime/print
%{_datadir}/nvim/runtime/print/*.ps

%dir %{_datadir}/nvim/runtime/queries/
%dir %{_datadir}/nvim/runtime/queries/c/
%{_datadir}/nvim/runtime/queries/c/highlights.scm
%{_datadir}/nvim/runtime/queries/c/injections.scm

%dir %{_datadir}/nvim/runtime/queries/help/
%{_datadir}/nvim/runtime/queries/help/highlights.scm
%{_datadir}/nvim/runtime/queries/help/injections.scm

%dir %{_datadir}/nvim/runtime/queries/lua/
%{_datadir}/nvim/runtime/queries/lua/highlights.scm
%{_datadir}/nvim/runtime/queries/lua/injections.scm

%dir %{_datadir}/nvim/runtime/queries/vim/
%{_datadir}/nvim/runtime/queries/vim/highlights.scm
%{_datadir}/nvim/runtime/queries/vim/injections.scm

%dir %{_datadir}/nvim/runtime/spell
%{_datadir}/nvim/runtime/spell/cleanadd.vim
%{_datadir}/nvim/runtime/spell/en.utf-8.spl

%dir %{_datadir}/nvim/runtime/syntax
%{_datadir}/nvim/runtime/syntax/*.vim
%{_datadir}/nvim/runtime/syntax/query.lua
%{_datadir}/nvim/runtime/syntax/shared/typescriptcommon.vim

%dir %{_datadir}/nvim/runtime/syntax/vim
%{_datadir}/nvim/runtime/syntax/vim/generated.vim

%dir %{_datadir}/nvim/runtime/tools
%{_datadir}/nvim/runtime/tools/check_colors.vim
%{_datadir}/nvim/runtime/tools/emoji_list.vim

%dir %{_datadir}/nvim/runtime/tutor
%{_datadir}/nvim/runtime/tutor/tutor.tutor
%{_datadir}/nvim/runtime/tutor/tutor.tutor.json

%dir %{_datadir}/nvim/runtime/tutor/en
%{_datadir}/nvim/runtime/tutor/en/vim-01-beginner.tutor
%{_datadir}/nvim/runtime/tutor/en/vim-01-beginner.tutor.json

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.8.2-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jan 16 2023 Shuo Wang <abushwang@tencent.com> - 0.8.2-1
- initial build
